@@ -71,7 +71,20 @@ class JNIFrameWork:
 		#endif
 		"""
 		return strHeader
-	
+
+	# For the extends (inheritance) support
+	def getHeaderInheritance(self):
+		strHeader="""
+		#ifndef FAKEGIWSDATATYPE
+		#define FAKEGIWSDATATYPE
+		namespace fakeGiwsDataType {
+		struct fakeGiwsDataType {
+		};
+		}
+		#endif
+		"""
+		return strHeader
+
 	def getJavaVMVariable(self):
 		return self.__JavaVMVariable
 	
@@ -79,12 +92,22 @@ class JNIFrameWork:
 		return self.__JavaVMVariableType
 
 	def getMethodGetCurrentEnv(self,objectName):
+		if configGiws().getThrowsException():
+			error = """throw %s::JniException(getCurrentEnv());"""%(configGiws().getExceptionFileName())
+
+		else:
+			error = """std::cerr << "Could not retrieve the current JVM." << std::endl;
+			exit(EXIT_FAILURE);
+			"""
 		return """
 		JNIEnv * %s::getCurrentEnv() {
 		JNIEnv * curEnv = NULL;
-		this->jvm->AttachCurrentThread(reinterpret_cast<void **>(&curEnv), NULL);
+		jint res=this->jvm->AttachCurrentThread(reinterpret_cast<void **>(&curEnv), NULL);
+		if (res != JNI_OK) {
+		%s
+		}
 		return curEnv;
-		}"""%(objectName)
+		}"""%(objectName, error)
 
 	
 	def getObjectDestuctor(self,objectName,stringClassSet=False):
@@ -180,7 +203,8 @@ class JNIFrameWork:
 		if method.getModifier()=="static":
 			methodCall="jmethodID"
 		else:
-			methodCall="""if (%s==NULL) { /* Use the cache Luke */"""%methodIdName
+			methodCall="""if (%s==NULL) { /* Use the cache */
+			"""%methodIdName
 
 		# Management of the error
 		if configGiws().getThrowsException():
@@ -228,10 +252,12 @@ class JNIFrameWork:
 
                 if method.getModifier()=="static":
                         return """
-                        %s curEnv->%s(cls, %s %s)%s;""" % (returns, returnType.getCallStaticMethod(), method.getUniqueNameOfTheMethod(), params, returnsEnd)
+                        %s curEnv->%s(cls, %s %s)%s;
+                        """ % (returns, returnType.getCallStaticMethod(), method.getUniqueNameOfTheMethod(), params, returnsEnd)
                 else:
                         return """
-                        %s curEnv->%s( this->instance, %s %s)%s;""" % (returns, returnType.getCallMethod(), method.getUniqueNameOfTheMethod(), params, returnsEnd)
+                        %s curEnv->%s( this->instance, %s %s)%s;
+                        """ % (returns, returnType.getCallMethod(), method.getUniqueNameOfTheMethod(), params, returnsEnd)
 		
 	def getReturnProfile(self, returnType):
 		return returnType.getReturnSyntax()
