@@ -39,14 +39,21 @@ from JNIFrameWork import JNIFrameWork
 from datatypes.stringDataGiws import stringDataGiws
 from configGiws import configGiws
 
-
 class objectGiws:
 	__name=""
 	__methods=[]
 	__stringClassSet=False
+	# Which class it extends
+	__extends=None
+
 	def __init__(self, name):
 		self.__name=name
 		self.__methods=[]
+
+	def __init__(self, name, extends):
+		self.__name=name
+		self.__methods=[]
+		self.__extends=extends
 		
 	def addMethod(self, method):
 		if isinstance(method,methodGiws):
@@ -75,6 +82,11 @@ class objectGiws:
 					curEnv->DeleteLocalRef(localStringArrayClass);
 					"""
 					stringClassSet=True
+
+		if self.getExtendedClass()!=None:
+			# Get the father object to work on it.
+			str+=self.getExtendedClass().__getDeclarationOfCachingMethodID()
+
 		return str
 	
 	def __getConstructorWhichInstanciateTheNewObject(self):
@@ -121,10 +133,13 @@ class objectGiws:
 			exit(EXIT_FAILURE);"""
 			
 		### Init the list of the cache of methodID
-		str=self.__getDeclarationOfCachingMethodID()
-			
-		return """
-		%s::%s {
+		strMethodID=self.__getDeclarationOfCachingMethodID()
+		constructorProfile="""%s::%s"""%(self.getName(), self.__getConstructorProfileWhichInstanciateTheNewObject())
+		if self.getExtendedClass()!=None:
+			constructorProfile+=""" : %s(fakeGiwsDataType::fakeGiwsDataType())""" % (self.getExtendedClass().getName())
+
+
+		return """%s {
 		jmethodID constructObject = NULL ;
 		jobject localInstance ;
 		jclass localClass ;
@@ -170,12 +185,12 @@ class objectGiws:
 		%s
 		
 		}
-		"""%(self.getName(), self.__getConstructorProfileWhichInstanciateTheNewObject(), errorMgntClass, errorMgntCreation, errorMgntConstructor, errorMgntInstantiate, errorMgntRef, str)
+		"""%(constructorProfile, errorMgntClass, errorMgntCreation, errorMgntConstructor, errorMgntInstantiate, errorMgntRef, strMethodID)
 
 		
 	def __getConstructorWhichUsesAnAlreadyExistingJObject(self):
 		### Init the list of the cache of methodID
-		str=self.__getDeclarationOfCachingMethodID()
+		strMethodID=self.__getDeclarationOfCachingMethodID()
 		
 		# Management of the error when the instance class could not be created a global ref
 		if configGiws().getThrowsException():
@@ -194,10 +209,11 @@ class objectGiws:
 			std::cerr << "Could not create a new global ref of " << this->className() << std::endl;
 			curEnv->ExceptionDescribe();
 			exit(EXIT_FAILURE);"""
-
-			   			   
+		constructorProfile="""%s::%s"""%(self.getName(), self.__getConstructorProfileWhichUsesAnAlreadyExistingJObject())
+		if self.getExtendedClass()!=None:
+			constructorProfile+=""" : %s(fakeGiwsDataType::fakeGiwsDataType()) """ % (self.getExtendedClass().getName())
 		return """
-		%s::%s {
+		%s {
         jvm=jvm_;
 
         JNIEnv * curEnv = getCurrentEnv();
@@ -218,8 +234,12 @@ class objectGiws:
         %s
 
 }
-		"""%(self.getName(), self.__getConstructorProfileWhichUsesAnAlreadyExistingJObject(), errorMgntRef, errorMgntNewRef, str)
-
+		"""%(constructorProfile, errorMgntRef, errorMgntNewRef, strMethodID)
+	
+	# Returns the class the current one is extending
+	# Returns None if not existing
+	def getExtendedClass(self):
+		return self.__extends
 		
 	def getConstructorBodyCXX(self):
 		str=self.__getConstructorWhichInstanciateTheNewObject()
@@ -227,7 +247,10 @@ class objectGiws:
 		return str
 
 	def __getConstructorProfileWhichInstanciateTheNewObject(self):
-	  return """%s(%s * %s_)"""% (self.getName(), JNIFrameWork().getJavaVMVariableType(), JNIFrameWork().getJavaVMVariable())
+	  str="""%s(%s * %s_)"""% (self.getName(), JNIFrameWork().getJavaVMVariableType(), JNIFrameWork().getJavaVMVariable())
+#	  if self.__extends!=None:
+#		  str+=""": %s(fakeGiwsDataType::fakeGiwsDataType())"""%(self.__extends)
+	  return str
 
   	def __getConstructorProfileWhichUsesAnAlreadyExistingJObject(self):
 	  return """%s(%s * %s_, jobject JObj)"""% (self.getName(), JNIFrameWork().getJavaVMVariableType(), JNIFrameWork().getJavaVMVariable())
@@ -238,6 +261,22 @@ class objectGiws:
 	def getConstructorWhichInstanciateTheNewObjectHeaderCXX(self):
 		return """%s;"""%self.__getConstructorProfileWhichInstanciateTheNewObject()
 
+	def __getFakeConstructorForExtendedClasses(self):
+		str=""
+		if self.getExtendedClass()==None:
+			# It is a potential master class, add the fake constructor
+			str+="""
+			/** 
+			* This is a fake constructor to avoid the constructor
+			* chaining when dealing with extended giws classes 
+			*/
+			#ifdef FAKEGIWSDATATYPE
+			%s(fakeGiwsDataType::fakeGiwsDataType /* unused */) {}
+			#endif
+			"""%(self.getName())
+			
+		return str
+
 	def getMethodsProfileForMethodIdCache(self):
 		str=""
 		stringClassSet=False
@@ -253,6 +292,17 @@ class objectGiws:
 					self.__stringClassSet=True
 		return str
 	
+	def getProtectedFields(self):
+		str=""
+		if self.getExtendedClass()==None:
+			str+="""
+			jobject instance;
+			jclass instanceClass; // cache class
+			"""
+		
+		return str
+
+
 	def getMethodsCXX(self, type="header"):
 		i=1
 		str=""
@@ -269,20 +319,26 @@ class objectGiws:
 		
         def generateCXXHeader(self, packageName):
                 JNIObjectName=packageName+"/"+self.getName()
-		return """
-		class %s {
+		if self.getExtendedClass()==None:
+			classProfile="""class %s {""" % (self.getName())
+		else:
+			classProfile="""class %s : public %s {
+			""" % (self.getName(), self.getExtendedClass().getName())
+		return """%s
+
 			private:
 			%s * %s;
-			jobject instance;
-			
-			jclass instanceClass; // cache class
+
+			protected:
 			%s
-			
+
+			%s
+
 			/**
 			* Get the environment matching to the current thread.
 			*/
-			JNIEnv * getCurrentEnv();
-			
+			virtual JNIEnv * getCurrentEnv();
+
 			public:
 			// Constructor
 			/**
@@ -291,6 +347,7 @@ class objectGiws:
 			* @param JEnv_ the Java Env
 			*/
 			%s
+
 			/**
 			* Create a wrapping of an already existing object from a JNIEnv.
 			* The object must have already been instantiated
@@ -299,6 +356,7 @@ class objectGiws:
 			*/
 			%s
 
+			%s
 			// Destructor
 			~%s();
 
@@ -326,7 +384,7 @@ class objectGiws:
                         %s
 			};
 
-			""" % (self.getName(),  JNIFrameWork().getJavaVMVariableType(), JNIFrameWork().getJavaVMVariable(), self.getMethodsProfileForMethodIdCache(), self.getConstructorWhichInstanciateTheNewObjectHeaderCXX(),self.getConstructorWhichUsesAnAlreadyExistingJObjectHeaderCXX(),self.getName(), self.getMethodsCXX(), self.getClassNameProfile(JNIObjectName)) 
+			""" % (classProfile, JNIFrameWork().getJavaVMVariableType(), JNIFrameWork().getJavaVMVariable(), self.getMethodsProfileForMethodIdCache(), self.getProtectedFields(), self.getConstructorWhichInstanciateTheNewObjectHeaderCXX(),self.getConstructorWhichUsesAnAlreadyExistingJObjectHeaderCXX(),self.__getFakeConstructorForExtendedClasses(), self.getName(), self.getMethodsCXX(), self.getClassNameProfile(JNIObjectName)) 
 
 	def generateCXXBody(self):
 		return """
