@@ -157,19 +157,21 @@ class stringDataGiws(dataGiws):
 		str=JNIFrameWork().getExceptionCheckProfile()
 
 		if self.isArray():
-			strCommon="""int lenRow;"""
+			strCommon=""
+			strDeclaration=""
+			if configGiws().getDisableReturnSize()==True:
+				strCommon+="int lenRow;"
+			else:
+				# The size of the array is returned as output argument of the function 
+				strDeclaration="*"
 			strCommon+="""
-			lenRow = curEnv->GetArrayLength(res);
-			"""
-			if configGiws().getDisableReturnSize()==False:
-				# When the user want the size in the argument
-				strCommon+="""*lenRowReturned=lenRow;"""
-			    
+			%s lenRow = curEnv->GetArrayLength(res);
+			"""%(strDeclaration)
 			if self.getDimensionArray() == 1:
-				return str+strCommon+"""
+				str+=strCommon+"""
 				char **arrayOfString;
-				arrayOfString = new char *[lenRow];
-				for (jsize i = 0; i < lenRow; i++){
+				arrayOfString = new char *[%slenRow];
+				for (jsize i = 0; i < %slenRow; i++){
 				jstring resString = reinterpret_cast<jstring>(curEnv->GetObjectArrayElement(res, i));
 				const char *tempString = curEnv->GetStringUTFChars(resString, 0);
 				arrayOfString[i] = new char[strlen(tempString) + 1];
@@ -178,19 +180,19 @@ class stringDataGiws(dataGiws):
 				curEnv->ReleaseStringUTFChars(resString, tempString);
 				curEnv->DeleteLocalRef(resString);
 				}
-				"""
+				"""%(strDeclaration, strDeclaration)
+				return str
 			else:
-				str+="int lenCol;"
-				if configGiws().getDisableReturnSize()==False:
-					str+="""*lenColReturned=lenCol;"""
-				return str+strCommon+"""
+				if configGiws().getDisableReturnSize()==True:
+					str+="int lenCol;"
+				str+=strCommon+"""
 				char ***arrayOfString;
-				arrayOfString = new char **[lenRow];
-				for (jsize i = 0; i < lenRow; i++){ /* Line of the array */
+				arrayOfString = new char **[%slenRow];
+				for (jsize i = 0; i < %slenRow; i++){ /* Line of the array */
 				jobjectArray resStringLine = reinterpret_cast<jobjectArray>(curEnv->GetObjectArrayElement(res, i));
-				lenCol = curEnv->GetArrayLength(resStringLine);
-				arrayOfString[i]=new char*[lenCol];
-				for (jsize j = 0; j < lenCol; j++){
+				%slenCol = curEnv->GetArrayLength(resStringLine);
+				arrayOfString[i]=new char*[%slenCol];
+				for (jsize j = 0; j < %slenCol; j++){
 				jstring resString = reinterpret_cast<jstring>(curEnv->GetObjectArrayElement(resStringLine, j));
 				const char *tempString = curEnv->GetStringUTFChars(resString, 0);
 				arrayOfString[i][j] = new char[strlen(tempString) + 1];
@@ -200,7 +202,8 @@ class stringDataGiws(dataGiws):
 }
 				curEnv->DeleteLocalRef(resStringLine);
 				 }
-				"""
+				"""%(strDeclaration, strDeclaration, strDeclaration, strDeclaration, strDeclaration)
+				return str
 
 		else:
 			if hasattr(self,"parameterName"):
